! ===================================================================================================\n
! MODULE        : tests_array
!
! CONTACT       : orchidee-help _at_ listes.ipsl.fr
!
! LICENCE       : IPSL (2006)
! This software is governed by the CeCILL licence see ORCHIDEE/ORCHIDEE_CeCILL.LIC
!
!>\BRIEF        
!!
!!\n DESCRIPTION : 
!!
!! RECENT CHANGE(S) : None
!!
!! REFERENCE(S) :
!!
!! SVN          :
!! $HeadURL: svn://forge.ipsl.jussieu.fr/orchidee/branches/ORCHIDEE-MICT/ORCHIDEE/src_sechiba/hydrol.f90 $
!! $Date: 2018-10-09 11:43:16 +0200 (Tue, 09 Oct 2018) $
!! $Revision: 5477 $
!! \n
!_ ===============================================================================================\n
MODULE tests_filelists

  USE ioipsl_para
  USE ioipsl_lists

  IMPLICIT NONE

  PRIVATE
  PUBLIC :: tests_filelists_main

  !
  ! variables used inside this module : declaration and initialisation
  !

CONTAINS

!! ================================================================================================================================
!! SUBROUTINE 	: tests_filelists_main
!!
!>\BRIEF         
!!
!! DESCRIPTION :
!!
!! MAIN OUTPUT VARIABLE(S) : 
!!
!! REFERENCE(S) : 
!!
!! FLOWCHART    : None
!! \n
!_ ================================================================================================================================
  SUBROUTINE tests_filelists_main()

    !! 0. Variable and parameter declaration

    !! 0.1 Input variables

  !_ ======================================================================================================
    CALL tests_setUp() ! Create list file
    CALL tests_filelists_nfiles()
    CALL tests_tearDown() ! Remove list file

    CALL tests_setUp() ! Create list file
    CALL tests_filelists_read()
    CALL tests_tearDown() ! Remove list file
          
  END SUBROUTINE tests_filelists_main
  
  SUBROUTINE tests_setUp()

    !! 0. Variable and parameter declaration

    !! 0.1 Input variables
    INTEGER, PARAMETER :: out_unit = 30

  !_ ======================================================================================================
    OPEN(unit=out_unit,file="nbcount.list",action="write",status="replace")  
    WRITE(out_unit,*) "   "
    WRITE(out_unit,*) "firstfile.nc   "
    WRITE(out_unit,*) "# some comment   "
    WRITE(out_unit,*) ""
    WRITE(out_unit,*) "secondfile.nc # some comment   "
    WRITE(out_unit,*) "   thirdfile.nc   "
    WRITE(out_unit,*) ""
    CLOSE(out_unit)

  END SUBROUTINE tests_setUp

  
  SUBROUTINE tests_tearDown()

    !! 0. Variable and parameter declaration

    !! 0.1 Input variables
    INTEGER, PARAMETER :: out_unit = 30

  !_ ======================================================================================================
    OPEN(unit=out_unit,file="nbcount.list",status="OLD")  
    CLOSE(out_unit, STATUS="DELETE")

  END SUBROUTINE tests_tearDown
!! ================================================================================================================================
!! SUBROUTINE 	: tests_filelists_read
!!
!>\BRIEF         
!!
!! DESCRIPTION :
!!
!! MAIN OUTPUT VARIABLE(S) : 
!!
!! REFERENCE(S) : 
!!
!! FLOWCHART    : None
!! \n
!_ ================================================================================================================================
  SUBROUTINE tests_filelists_read()

    !! 0. Variable and parameter declaration

    !! 0.1 Input variables
    TYPE(t_file_def_list) :: flist
    CHARACTER(LEN=:), ALLOCATABLE :: test_title

    CHARACTER(LEN=100), DIMENSION(3), PARAMETER :: expected_files = (/ 'firstfile.nc', 'secondfile.nc', 'thirdfile.nc' /)

  !_ ======================================================================================================
    WRITE(*,*) "========================================================================"
    test_title = "tests_filelists_read" 
    WRITE(*,*) "Test "//test_title

    flist = t_file_def_list("nbcount.list")

    IF ( flist%get_file(1) .EQ. expected_files(1) .AND. &
         flist%get_file(2) .EQ. expected_files(2) .AND. &
         flist%get_file(3) .EQ. expected_files(3) ) THEN
       WRITE(*,*) "Test "//test_title//": Successful"
    ELSE
       WRITE(*,*) "Test "//test_title//": failed"
       WRITE(*,*) "Expected:", expected_files
       WRITE(*,*) "Found(1):", flist%get_file(1)
       WRITE(*,*) "Found(2):", flist%get_file(2)
       WRITE(*,*) "Found(3):", flist%get_file(3)
    ENDIF
          
  END SUBROUTINE tests_filelists_read

!! ================================================================================================================================
!! SUBROUTINE 	: tests_filelists_nfiles
!!
!>\BRIEF         
!!
!! DESCRIPTION :
!!
!! MAIN OUTPUT VARIABLE(S) : 
!!
!! REFERENCE(S) : 
!!
!! FLOWCHART    : None
!! \n
!_ ================================================================================================================================
  SUBROUTINE tests_filelists_nfiles()

    !! 0. Variable and parameter declaration

    !! 0.1 Input variables
    TYPE(t_file_def_list) :: flist
    CHARACTER(LEN=:), ALLOCATABLE :: test_title

    INTEGER :: nbfiles = 0
    INTEGER, PARAMETER :: expected_nbfiles = 3

  !_ ======================================================================================================
    WRITE(*,*) "========================================================================"
    test_title = "tests_filelists_nfiles"  
    WRITE(*,*) "Test "//test_title

    flist = t_file_def_list("nbcount.list")
    nbfiles = flist%get_num_files()

    IF ( nbfiles .EQ. expected_nbfiles ) THEN 
       WRITE(*,*) "Test "//test_title//": Successful"
    ELSE
       WRITE(*,*) "Test "//test_title//": failed"
       WRITE(*,*) "Expected:", expected_nbfiles
       WRITE(*,*) "Found:", nbfiles
    ENDIF
          
  END SUBROUTINE tests_filelists_nfiles
  
  
END MODULE tests_filelists
